# Generated by Django 5.0.14 on 2025-07-21 19:22

import encrypted_model_fields.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0004_alter_connectionapi_unique_together'),
    ]

    operations = [
        migrations.AlterField(
            model_name='connectionapi',
            name='password',
            field=encrypted_model_fields.fields.EncryptedCharField(),
        ),
    ]
