# Generated by Django 5.0.9 on 2025-06-24 17:27

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='userapi',
            name='branch',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='isapilib.branchapi'),
        ),
    ]
