# Generated by Django 5.0.14 on 2025-07-19 16:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0003_usuario_alter_connectionapi_port_and_more'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='connectionapi',
            unique_together={('host', 'port', 'nombre_db')},
        ),
    ]
