# Generated by Django 5.0.14 on 2025-07-18 19:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0002_userapi_branch'),
    ]

    operations = [
        migrations.CreateModel(
            name='Usuario',
            fields=[
                ('usuario', models.CharField(db_column='Usuario', max_length=10, primary_key=True, serialize=False)),
                ('nombre', models.CharField(db_column='Nombre', max_length=100)),
                ('sucursal', models.IntegerField(db_column='Sucursal')),
                ('email', models.CharField(db_column='eMail', max_length=50)),
                ('estatus', models.CharField(db_column='Estatus', default='ALTA', max_length=15)),
            ],
            options={
                'db_table': 'Usuario',
                'managed': False,
            },
        ),
        migrations.AlterField(
            model_name='connectionapi',
            name='port',
            field=models.CharField(blank=True, max_length=80, null=True),
        ),
        migrations.AlterModelTable(
            name='branchapi',
            table='isapilib_branchapi',
        ),
        migrations.AlterModelTable(
            name='connectionapi',
            table='isapilib_connectionapi',
        ),
        migrations.AlterModelTable(
            name='permissionapi',
            table='isapilib_permissionapi',
        ),
        migrations.AlterModelTable(
            name='userapi',
            table='isapilib_userapi',
        ),
    ]
